// This adapter uses localStorage for content storage when running in the browser

const STORAGE_KEY = "the-one-token-content"

// Default content structure
const defaultContent = {
  hero: {
    title: "The Future of Cryptocurrency",
    description:
      "Our revolutionary crypto project, The One Token, is leading the transition from Web3 to Web4. With cutting-edge technology and a dynamic vision, we are shaping the future of decentralized finance.",
  },
  features: [
    {
      title: "What is The One Token?",
      items: [
        "Token Details: The One Token is a revolutionary cryptocurrency designed to power the future of finance.",
        "Ecosystem Integration: Seamlessly integrates into existing and emerging financial systems.",
        "Token Purpose: Acts as a bridge between traditional finance and the decentralized world.",
      ],
    },
    {
      title: "The One Token Ecosystem",
      items: [
        "Web3 Applications: Provides the foundation for innovative Web3 to Web4 applications.",
        "Digitisation of Real World Assets: Features digitisation of assets that generate real-world profits.",
        "Multi Chain Support: Supported on multiple chains to accommodate low fees.",
      ],
    },
  ],
  roadmap: [
    {
      title: "Phase 1: Development",
      description:
        "Focuses on building the core infrastructure and functionalities of The One Token. This is already done.",
    },
    {
      title: "Phase 2: Launch and Expansion",
      description:
        "The One Token is launched and integrated into the wider crypto ecosystem first on Smart Chain and soon to other L2's.",
    },
    {
      title: "Phase 3: Ecosystem Growth",
      description:
        "We will start to roll out (RWA) Real World Assets and applications Focused on building a new ecosystem of applications and services powered by The One Token.",
    },
  ],
  tokenomics: [
    {
      title: "Soaring Token Scarcity",
      description:
        "The revolutionary One Token features a dynamic burn mechanism that systematically reduces the total supply over time.",
    },
    {
      title: "Unleash the Power of Our Token",
      description:
        "Jump into our thriving community and unlock a world of rewarding incentives through our innovative token distribution model.",
    },
    {
      title: "Endless Possibilities with The One Token",
      description:
        "From powering transactions to unlocking exclusive rewards, the limitless use cases of the One Token make it the ultimate cryptocurrency for your digital life.",
    },
  ],
  advantages: [
    {
      title: "More ways to earn",
      description:
        "The One Token utilises advanced Tokenomics features to ensure the most advantageous to its holders. Tax system that is paid to all holders in stable coins.",
    },
    {
      title: "There is no team allocation of tokens",
      description:
        "The One Token operates on a commission based tax system so we have to keep working for you to get paid. This is a next first in the crypto space.",
    },
    {
      title: "Dividend distribution System",
      description:
        "The One Token is designed to distribute dividend from Real World Assets to holders according to the percentage of tokens held by all users in Stable Coins.",
    },
  ],
  communities: [
    {
      name: "Telegram",
      icon: "MessageCircle",
      description: "Join our Telegram group for real-time discussions and community support.",
      url: "https://t.me/TheOneTokenWeb4",
    },
    {
      name: "YouTube",
      icon: "Youtube",
      description: "Connect with other enthusiasts on our YouTube channel for community events and discussions.",
      url: "https://www.youtube.com/channel/UCPslQID_9oGDc1oVREbMZGA",
    },
    {
      name: "TikTok",
      icon: "BookOpen",
      description: "Follow us on TikTok for the latest video updates and content.",
      url: "https://www.tiktok.com/@theonetoken?_t=8sdCp3M899p&_r=1",
    },
  ],
}

export function getLocalContent() {
  if (typeof window === "undefined") {
    return defaultContent
  }

  try {
    const storedContent = localStorage.getItem(STORAGE_KEY)
    return storedContent ? JSON.parse(storedContent) : defaultContent
  } catch (error) {
    console.error("Error reading from localStorage:", error)
    return defaultContent
  }
}

export function updateLocalContent(content: any) {
  if (typeof window === "undefined") {
    return
  }

  try {
    localStorage.setItem(STORAGE_KEY, JSON.stringify(content))
  } catch (error) {
    console.error("Error writing to localStorage:", error)
  }
}

